summaryrefslogtreecommitdiff
path: root/lib/parameters.py
diff options
context:
space:
mode:
Diffstat (limited to 'lib/parameters.py')
-rw-r--r--lib/parameters.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/lib/parameters.py b/lib/parameters.py
index bafc2a5..acc77d4 100644
--- a/lib/parameters.py
+++ b/lib/parameters.py
@@ -598,7 +598,7 @@ class ModelAttribute:
# There must be at least 3 distinct data values (≠ None) if an analytic model
# is to be fitted. For 2 (or fewer) values, decision trees are better.
# Exceptions such as DFATOOL_SUBMODEL=fol (2 values sufficient)
# can be handled via DFATOOL_ULS_MIN_DISTINCT_VALUES
self.min_values_for_analytic_model = int(
os.getenv("DFATOOL_ULS_MIN_DISTINCT_VALUES", "3")
@@ -1031,9 +1031,10 @@ class ModelAttribute:
"""
if with_function_leaves is None:
- with_function_leaves = bool(
- int(os.getenv("DFATOOL_RMT_FUNCTION_LEAVES", "1"))
- )
+ if os.getenv("DFATOOL_RMT_SUBMODEL", "uls") == "static":
+ with_function_leaves = False
+ else:
+ with_function_leaves = True
if with_nonbinary_nodes is None:
with_nonbinary_nodes = bool(
int(os.getenv("DFATOOL_RMT_NONBINARY_NODES", "1"))
@@ -598,7 +598,7 @@ class ModelAttribute:
# There must be at least 3 distinct data values (≠ None) if an analytic model
# is to be fitted. For 2 (or fewer) values, decision trees are better.
- # Exceptions such as DFATOOL_SUBMODEL=fol (2 values sufficient)
+ # Exceptions such as DFATOOL_RMT_SUBMODEL=fol (2 values sufficient)
# can be handled via DFATOOL_ULS_MIN_DISTINCT_VALUES
self.min_values_for_analytic_model = int(